@@ -1,11 +1,7 @@
 """Factories for the models of the ``django-crowdsourced-fields`` app."""
 import factory
 
-from crowdsourced_fields.models import (
-    CrowdsourcedItem,
-    CrowdsourcedItemGenericForeignKey,
-)
-
+from crowdsourced_fields.models import CrowdsourcedItem
 
 
 class CrowdsourcedItemFactory(factory.Factory):
