@@ -7,11 +7,13 @@ from crowdsourced_fields.tests.test_app.forms import DummyModelForm
 
 class CrowdsourcedFieldsFormMixinTestCase(TestCase):
     """Tests for the ``CrowdsourcedFieldsFormMixin`` mixin."""
+    longMessage = True
+
     def test_mixin(self):
         create_fixtures(self)
         form = DummyModelForm()
         result = form.country_crowdsourced_values()
-        self.assertEqual(result, '["Germany"]', msg=(
+        self.assertEqual(result, '["Germany", "Singapore"]', msg=(
             'Should add ``fieldname_crowdsourced_values`` methods to the form'
             " and these methods should return all values for that fields's"
             " item type"))
