@@ -9,6 +9,7 @@ class DummyModel(CrowdsourcedFieldsModelMixin, models.Model):
     """Dummy model needed for testing purposes."""
     CROWDSOURCED_FIELDS = {
         'country': {'item_type': 'countries', },
+        'country2': {'item_type': 'countries', },
         'title': {'item_type': 'titles', },
     }
 
@@ -26,3 +27,8 @@ class DummyModel(CrowdsourcedFieldsModelMixin, models.Model):
         max_length=256,
         verbose_name=_('Country'),
     )
+
+    country2 = models.CharField(
+        max_length=256,
+        verbose_name=_('Country2'),
+    )
